@@ -4,7 +4,7 @@
  *	Stub object that will be statically linked into extensions that want
  *	to access Tcl.
  *
- * Copyright (c) 1998-1999 by Scriptics Corporation.
+ * Copyright (c) 1998-1999 Scriptics Corporation.
  * Copyright (c) 1998 Paul Duffin.
  *
  * See the file "license.terms" for information on usage and redistribution of
@@ -24,13 +24,10 @@ const TclIntStubs *tclIntStubsPtr = NULL;
 const TclIntPlatStubs *tclIntPlatStubsPtr = NULL;
 
 /*
- * Use our own isDigit to avoid linking to libc on windows
+ * Use our own ISDIGIT to avoid linking to libc on windows
  */
 
-static int isDigit(const int c)
-{
-    return (c >= '0' && c <= '9');
-}
+#define ISDIGIT(c) (((unsigned)((c)-'0')) <= 9)
 
 /*
  *----------------------------------------------------------------------
@@ -56,9 +53,9 @@ Tcl_InitStubs(
     const char *version,
     int exact)
 {
-    Interp *iPtr = (Interp *) interp;
+    Interp *iPtr = (Interp *)interp;
     const char *actualVersion = NULL;
-    ClientData pkgData = NULL;
+    void *pkgData = NULL;
     const TclStubs *stubsPtr = iPtr->stubTable;
 
     /*
@@ -68,21 +65,36 @@ Tcl_InitStubs(
      */
 
     if (!stubsPtr || (stubsPtr->magic != TCL_STUB_MAGIC)) {
-	iPtr->result = "interpreter uses an incompatible stubs mechanism";
-	iPtr->freeProc = TCL_STATIC;
+	exact &= 0xFFFF00; /* Filter out minor/major Tcl version */
+	if (!exact) {
+	    exact = 0x060800;
+	}
+	if (stubsPtr && (stubsPtr->magic == ((int)0xFCA3BACB + (int)sizeof(void *)))
+		&& ((exact|0x010000) == 0x070800)) {
+	    /* We are running in Tcl 9.x, but extension is compiled with 8.6 */
+	    stubsPtr->tcl_SetObjResult(interp, stubsPtr->tcl_ObjPrintf(
+		    "this extension is compiled for Tcl %d.%d",
+		    (exact & 0x0FF00)>>8, (exact & 0x0FF0000)>>16));
+	} else {
+	    iPtr->result = (char *)"interpreter uses an incompatible stubs mechanism";
+	    iPtr->freeProc = TCL_STATIC;
+	}
 	return NULL;
     }
 
     actualVersion = stubsPtr->tcl_PkgRequireEx(interp, "Tcl", version, 0, &pkgData);
     if (actualVersion == NULL) {
+	/* Even when the Tcl version does not match, the caller should at least be
+	 * able to use Tcl_GetObjResult/Tcl_GetString/Tcl_Panic for error-handling */
+	tclStubsPtr = stubsPtr; /* See: [fd8341e496] */
 	return NULL;
     }
-    if (exact) {
+    if (exact&1) {
 	const char *p = version;
 	int count = 0;
 
 	while (*p) {
-	    count += !isDigit(*p++);
+	    count += !ISDIGIT(*p++);
 	}
 	if (count == 1) {
 	    const char *q = actualVersion;
@@ -91,7 +103,7 @@ Tcl_InitStubs(
 	    while (*p && (*p == *q)) {
 		p++; q++;
 	    }
-	    if (*p || isDigit(*q)) {
+	    if (*p || ISDIGIT(*q)) {
 		/* Construct error message */
 		stubsPtr->tcl_PkgRequireEx(interp, "Tcl", version, 1, NULL);
 		return NULL;
