@@ -6,10 +6,8 @@
  *
  * Copyright (c) 1995-1997 Sun Microsystems, Inc.
  *
- * See the file "license.terms" for information on usage and redistribution of
- * this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tclLoadDl.c,v 1.16 2006/06/13 22:10:19 dkf Exp $
+ * See the file "license.terms" for information on usage and redistribution
+ * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
 #include "tclInt.h"
@@ -21,19 +19,27 @@
 
 /*
  * In some systems, like SunOS 4.1.3, the RTLD_NOW flag isn't defined and this
- * argument to dlopen must always be 1. The RTLD_GLOBAL flag is needed on some
- * systems (e.g. SCO and UnixWare) but doesn't exist on others; if it doesn't
- * exist, set it to 0 so it has no effect.
+ * argument to dlopen must always be 1. The RTLD_LOCAL flag doesn't exist on
+ * some platforms; if it doesn't exist, set it to 0 so it has no effect.
+ * See [Bug #3216070]
  */
 
 #ifndef RTLD_NOW
 #   define RTLD_NOW 1
 #endif
 
-#ifndef RTLD_GLOBAL
-#   define RTLD_GLOBAL 0
+#ifndef RTLD_LOCAL
+#   define RTLD_LOCAL 0
 #endif
 
+/*
+ * Static procedures defined within this file.
+ */
+
+static void *		FindSymbol(Tcl_Interp *interp,
+			    Tcl_LoadHandle loadHandle, const char *symbol);
+static void		UnloadFile(Tcl_LoadHandle loadHandle);
+
 /*
  *---------------------------------------------------------------------------
  *
@@ -60,13 +66,16 @@ TclpDlopen(
     Tcl_LoadHandle *loadHandle,	/* Filled with token for dynamically loaded
 				 * file which will be passed back to
 				 * (*unloadProcPtr)() to unload the file. */
-    Tcl_FSUnloadFileProc **unloadProcPtr)
+    Tcl_FSUnloadFileProc **unloadProcPtr,
 				/* Filled with address of Tcl_FSUnloadFileProc
 				 * function which should be used for this
 				 * file. */
+    int flags)
 {
     void *handle;
-    CONST char *native;
+    Tcl_LoadHandle newHandle;
+    const char *native;
+    int dlopenflags = 0;
 
     /*
      * First try the full path the user gave us. This is particularly
@@ -74,8 +83,21 @@ TclpDlopen(
      * relative path.
      */
 
-    native = Tcl_FSGetNativePath(pathPtr);
-    handle = dlopen(native, RTLD_NOW | RTLD_GLOBAL);
+    native = (const char *)Tcl_FSGetNativePath(pathPtr);
+    /*
+     * Use (RTLD_NOW|RTLD_LOCAL) as default, see [Bug #3216070]
+     */
+    if (flags & TCL_LOAD_GLOBAL) {
+	dlopenflags |= RTLD_GLOBAL;
+    } else {
+	dlopenflags |= RTLD_LOCAL;
+    }
+    if (flags & TCL_LOAD_LAZY) {
+	dlopenflags |= RTLD_LAZY;
+    } else {
+	dlopenflags |= RTLD_NOW;
+    }
+    handle = dlopen(native, dlopenflags);
     if (handle == NULL) {
 	/*
 	 * Let the OS loader examine the binary search path for whatever
@@ -84,10 +106,13 @@ TclpDlopen(
 	 */
 
 	Tcl_DString ds;
-	char *fileName = Tcl_GetString(pathPtr);
+	const char *fileName = TclGetString(pathPtr);
 
 	native = Tcl_UtfToExternalDString(NULL, fileName, -1, &ds);
-	handle = dlopen(native, RTLD_NOW | RTLD_GLOBAL);
+	/*
+	 * Use (RTLD_NOW|RTLD_LOCAL) as default, see [Bug #3216070]
+	 */
+	handle = dlopen(native, dlopenflags);
 	Tcl_DStringFree(&ds);
     }
 
@@ -99,20 +124,27 @@ TclpDlopen(
 
 	const char *errorStr = dlerror();
 
-	Tcl_AppendResult(interp, "couldn't load file \"",
-		Tcl_GetString(pathPtr), "\": ", errorStr, NULL);
+	if (interp) {
+	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
+		    "couldn't load file \"%s\": %s",
+		    TclGetString(pathPtr), errorStr));
+	}
 	return TCL_ERROR;
     }
+    newHandle = (Tcl_LoadHandle)ckalloc(sizeof(*newHandle));
+    newHandle->clientData = handle;
+    newHandle->findSymbolProcPtr = &FindSymbol;
+    newHandle->unloadFileProcPtr = &UnloadFile;
+    *unloadProcPtr = &UnloadFile;
+    *loadHandle = newHandle;
 
-    *unloadProcPtr = &TclpUnloadFile;
-    *loadHandle = (Tcl_LoadHandle) handle;
     return TCL_OK;
 }
 
 /*
  *----------------------------------------------------------------------
  *
- * TclpFindSymbol --
+ * FindSymbol --
  *
  *	Looks up a symbol, by name, through a handle associated with a
  *	previously loaded piece of code (shared library).
@@ -125,16 +157,21 @@ TclpDlopen(
  *----------------------------------------------------------------------
  */
 
-Tcl_PackageInitProc *
-TclpFindSymbol(
+static void *
+FindSymbol(
     Tcl_Interp *interp,		/* Place to put error messages. */
     Tcl_LoadHandle loadHandle,	/* Value from TcpDlopen(). */
-    CONST char *symbol)		/* Symbol to look up. */
+    const char *symbol)		/* Symbol to look up. */
 {
-    CONST char *native;
-    Tcl_DString newName, ds;
-    VOID *handle = (VOID*)loadHandle;
-    Tcl_PackageInitProc *proc;
+    const char *native;		/* Name of the library to be loaded, in
+				 * system encoding */
+    Tcl_DString newName, ds;	/* Buffers for converting the name to
+				 * system encoding and prepending an
+				 * underscore*/
+    void *handle = loadHandle->clientData;
+				/* Native handle to the loaded library */
+    void *proc;			/* Address corresponding to the resolved
+				 * symbol */
 
     /*
      * Some platforms still add an underscore to the beginning of symbol
@@ -143,49 +180,58 @@ TclpFindSymbol(
      */
 
     native = Tcl_UtfToExternalDString(NULL, symbol, -1, &ds);
-    proc = (Tcl_PackageInitProc *) dlsym(handle,	/* INTL: Native. */
-	    native);
+    proc = dlsym(handle, native);	/* INTL: Native. */
     if (proc == NULL) {
 	Tcl_DStringInit(&newName);
-	Tcl_DStringAppend(&newName, "_", 1);
+	TclDStringAppendLiteral(&newName, "_");
 	native = Tcl_DStringAppend(&newName, native, -1);
-	proc = (Tcl_PackageInitProc *) dlsym(handle,	/* INTL: Native. */
-		native);
+	proc = dlsym(handle, native);	/* INTL: Native. */
 	Tcl_DStringFree(&newName);
     }
     Tcl_DStringFree(&ds);
+    if (proc == NULL) {
+	const char *errorStr = dlerror();
 
+	if (interp) {
+	    if (!errorStr) {
+		errorStr = "unknown";
+	    }
+	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
+		    "cannot find symbol \"%s\": %s", symbol, errorStr));
+	    Tcl_SetErrorCode(interp, "TCL", "LOOKUP", "LOAD_SYMBOL", symbol,
+		    (char *)NULL);
+	}
+    }
     return proc;
 }
 
 /*
  *----------------------------------------------------------------------
  *
- * TclpUnloadFile --
+ * UnloadFile --
  *
- *	Unloads a dynamically loaded binary code file from memory. Code
- *	pointers in the formerly loaded file are no longer valid after calling
- *	this function.
+ *	Unloads a dynamic shared object, after which all pointers to functions
+ *	in the formerly-loaded object are no longer valid.
  *
  * Results:
  *	None.
  *
  * Side effects:
- *	Code removed from memory.
+ *	Memory for the loaded object is deallocated.
  *
  *----------------------------------------------------------------------
  */
 
-void
-TclpUnloadFile(
+static void
+UnloadFile(
     Tcl_LoadHandle loadHandle)	/* loadHandle returned by a previous call to
 				 * TclpDlopen(). The loadHandle is a token
 				 * that represents the loaded file. */
 {
-    void *handle;
+    void *handle = loadHandle->clientData;
 
-    handle = (void *) loadHandle;
     dlclose(handle);
+    ckfree(loadHandle);
 }
 
 /*
@@ -210,7 +256,7 @@ TclpUnloadFile(
 
 int
 TclGuessPackageName(
-    CONST char *fileName,	/* Name of file containing package (already
+    const char *fileName,	/* Name of file containing package (already
 				 * translated to local form if needed). */
     Tcl_DString *bufPtr)	/* Initialized empty dstring. Append package
 				 * name to this if possible. */
@@ -218,6 +264,38 @@ TclGuessPackageName(
     return 0;
 }
 
+/*
+ * These functions are fallbacks if we somehow determine that the platform can
+ * do loading from memory but the user wishes to disable it. They just report
+ * (gracefully) that they fail.
+ */
+
+#ifdef TCL_LOAD_FROM_MEMORY
+
+MODULE_SCOPE void *
+TclpLoadMemoryGetBuffer(
+     size_t size)		/* Dummy: unused by this implementation */
+{
+    return NULL;
+}
+
+MODULE_SCOPE int
+TclpLoadMemory(
+    void *buffer,		/* Dummy: unused by this implementation */
+    size_t size,		/* Dummy: unused by this implementation */
+    int codeSize,		/* Dummy: unused by this implementation */
+    const char *path,	/* Dummy: unused by this implementation */
+    Tcl_LoadHandle *loadHandle,	/* Dummy: unused by this implementation */
+    Tcl_FSUnloadFileProc **unloadProcPtr,
+				/* Dummy: unused by this implementation */
+    int flags)
+				/* Dummy: unused by this implementation */
+{
+    return TCL_ERROR;
+}
+
+#endif /* TCL_LOAD_FROM_MEMORY */
+
 /*
  * Local Variables:
  * mode: c
