@@ -12,7 +12,9 @@
  */
 
 #include "tclWinInt.h"
-#if defined(HAVE_INTRIN_H)
+#if defined(HAVE_CPUID_H)
+#   include <cpuid.h>
+#elif defined(HAVE_INTRIN_H)
 #   include <intrin.h>
 #endif
 
@@ -661,7 +663,12 @@ TclWinCPUID(
 {
     int status = TCL_ERROR;
 
-#if defined(HAVE_INTRIN_H) && defined(_WIN64) && defined(HAVE_CPUID)
+#if defined(HAVE_CPUID_H)
+
+    __get_cpuid(index, &regsPtr[0], &regsPtr[1], &regsPtr[2], &regsPtr[3]);
+    status = TCL_OK;
+
+#elif defined(HAVE_INTRIN_H) && defined(_WIN64) && defined(HAVE_CPUID)
 
     __cpuid((int *)regsPtr, (int)index);
     status = TCL_OK;
